@@ -269,7 +269,7 @@ class TickerDax:
         if os.environ.get(Envs.OFFICIAL_DOCKER_IMAGE.value) and attempts < 1:
             try:
                 subprocess.Popen(
-                    f'redis-server /var/tickerdax --port {self._redis_host_port}',
+                    f'redis-server {self._cache_folder} --port {self._redis_host_port}',
                     shell=True
                 )
                 self._logger.info('Attempting to start redis server on local system...')
