@@ -36,6 +36,10 @@ class Envs(BaseEnum):
         f'{NAME.upper()}_CONFIG',
         'A file path to the config file for the CLI.'
     )
+    LOGS_FOLDER = (
+        f'{NAME.upper()}_LOGS_FOLDER',
+        'A folder path where the logs will be saved.'
+    )
     EMAIL = (
         f'{NAME.upper()}_EMAIL',
         'Your email linked to your tickerdax.com account.'
